"""Main package for Munter.py"""
__version__ = '2.2.1'
__progname__ = 'Munter.py'
from .munter import time_calc
